@@ -52,9 +52,13 @@ class TqdmDeprecationWarning(Exception):
 # works only if fork available (Linux, MacOSX, but not on Windows)
 try:
     mp_lock = mp.RLock()  # multiprocessing lock
-    th_lock = th.RLock()  # thread lock
+except ImportError:  # pragma: no cover
+    mp_lock = None
 except OSError:  # pragma: no cover
     mp_lock = None
+try:
+    th_lock = th.RLock()  # thread lock
+except OSError:  # pragma: no cover
     th_lock = None
 
 
@@ -189,7 +193,7 @@ class tqdm(object):
         out  : str
             Number with Order of Magnitude SI unit postfix.
         """
-        for unit in ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z']:
+        for unit in ['', 'k', 'M', 'G', 'T', 'P', 'E', 'Z']:
             if abs(num) < 999.95:
                 if abs(num) < 99.95:
                     if abs(num) < 9.995:
@@ -276,7 +280,7 @@ class tqdm(object):
             The iteration unit [default: 'it'].
         unit_scale  : bool or int or float, optional
             If 1 or True, the number of iterations will be printed with an
-            appropriate SI metric prefix (K = 10^3, M = 10^6, etc.)
+            appropriate SI metric prefix (k = 10^3, M = 10^6, etc.)
             [default: False]. If any other non-zero number, will scale
             `total` and `n`.
         rate  : float, optional
@@ -448,6 +452,8 @@ class tqdm(object):
         # Add to the list of instances
         if "_instances" not in cls.__dict__:
             cls._instances = WeakSet()
+        if "_lock" not in cls.__dict__:
+            cls._lock = TqdmDefaultWriteLock()
         with cls._lock:
             cls._instances.add(instance)
         # Create the monitoring thread
